"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Cache = void 0;
const node_events_1 = require("node:events");
const Ignite = __importStar(require("apache-ignite-client"));
const loggerModule = __importStar(require("@koopjs/logger"));
const config_1 = __importDefault(require("config"));
const IgniteClient = Ignite.default;
const { default: Logger } = loggerModule;
const CacheConfiguration = Ignite.CacheConfiguration;
const ObjectType = Ignite.ObjectType;
const IgniteClientConfiguration = Ignite.IgniteClientConfiguration;
class Cache extends node_events_1.EventEmitter {
    constructor(params = {}) {
        var _a, _b;
        super();
        this.logger = params.logger || new Logger();
        this.config = config_1.default.has('apacheIgnite')
            ? config_1.default.get('apacheIgnite')
            : {};
        const igniteClient = new IgniteClient();
        const connStr = ((_a = params.options) === null || _a === void 0 ? void 0 : _a.connStr) || this.config.connStr || '127.0.0.1:10800';
        const cacheName = ((_b = params.options) === null || _b === void 0 ? void 0 : _b.cacheName) || this.config.cacheName || 'koop-cache';
        const igniteClientConfig = new IgniteClientConfiguration(connStr);
        igniteClient
            .connect(igniteClientConfig)
            .then(() => {
            const cacheConfig = new CacheConfiguration();
            return igniteClient.getOrCreateCache(cacheName, cacheConfig);
        })
            .then((cache) => {
            this.cache = cache;
            this.cache.setKeyType(ObjectType.PRIMITIVE_TYPE.STRING);
            this.logger.info(`apache-ignite connection established, "${cacheName}" ready`);
            this.emit('apache-connected');
            return;
        })
            .catch((error) => {
            this.logger.error(`could not establish apache-ignite connection`);
            this.logger.error(error);
            this.emit('error', error);
        });
    }
    insert(key, data, options) {
        return __awaiter(this, void 0, void 0, function* () {
            if (!options.ttl) {
                return;
            }
            const cacheEntry = {
                data,
                expires: Date.now() + options.ttl * 1000,
            };
            return this.cache.put(key, JSON.stringify(cacheEntry));
        });
    }
    retrieve(key) {
        return __awaiter(this, void 0, void 0, function* () {
            const stringVal = yield this.cache.get(key);
            if (stringVal) {
                const val = JSON.parse(stringVal);
                if (Date.now() > val.expires) {
                    yield this.cache.removeKey(key);
                    return null;
                }
                return val.data;
            }
            return null;
        });
    }
    delete(key) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.cache.removeKey(key);
        });
    }
}
exports.Cache = Cache;
Cache.pluginName = 'Apache Ignite Cache';
Cache.type = 'cache';
//# sourceMappingURL=index.js.map